---
title: Rasa Chatbot Demo
separator: <!--s-->
verticalSeparator: <!--v-->
theme: solarized
revealOptions:
    transition: fade
    controls: false
    
---

# Wikipedia Fact Chatbot

David Fuhry, Lukas Gehrke, Leonard Haas, 

Lucas Schons, Jonas Wolff

<!--s-->

### Inhalt

* Thema & Forschungsfrage
* Lösungsansatz
* Ergebnisse

<!--s-->

### Thema - RASA Chatbot
<section style="text-align: left;">
RASA ist ein Framework für die Nutzung von **Chatbots** im Bereich _Conversational AI_. Das System muss mit Facts befüllt werden, um Antworten generieren zu können.

_"The Rasa Stack is a set of open source machine learning tools for developers to create contextual chatbots and assistants."_

<!--s-->

### Thema - Architektur von RASA

<img src="plots/rasa_architecture.png" width="70%">
Note: Bild von Rasa NLU und Core Architektur erklären

<!--s-->

### Forschungsfrage

- _Kann man dieses Wissen aus Texten akquirieren?_  
- _Kann dies automatisch mit Textquellen durchgeführt werden?_  

Dies soll anhand der _Wikipedia-Einträge von Physikern_ erprobt werden

<!--s-->

### Inhalt

* ~~Thema & Forschungsfrage~~
* Lösungsansatz
* Ergebnisse

<!--s-->

### Lösungsansatz - RASA Bot konfigurierern

* Für Training eines Bots werden _entities_, _text_ und _intents_ benötigt
* Definition _intent_ aus [RASA Docs](https://rasa.com/docs/nlu/dataformat/):  
_"The intent is the intent that should be associated with the text."_

<!--s-->

### Lösungsansatz - RASA Bot konfigurierern

<section style="text-align: left;">
#### Aufstellen von Intents zu Physikern:
* birthplace
* area_of_research
* spouse
* university
* ... 

<!--s-->

### Lösungsansatz - Datenquelle

* 982 englischsprachige Wikipedia-Artikel
* Scraping über jeweiligen Link mit `wikipediR`
* HTML-Formatierung
* Ca. 550 Wörter/Artikel
<img src="aarons.png" width="70%">
Note: Bild zu dem Artikel von irgendeinem sowjetischen Physiker :)

<!--s-->

### Lösungsansatz - Processing

```
├── packages.list
├── script
│   └── master.R
└── wikiproc
    ├── DESCRIPTION
    ├── NAMESPACE
    ├── R
    │   ├── get_awards.R
    │   ├── get_birthdate.R
    │   ├── get_birthplace.R
    │   ├── get_data.R
    │   ├── get_spouse.R
    │   └── get_university.R
    ├── man
    └── tests
```
Note: Zu jedem Intent ein R-Skript. Master lädt die Artikel, speichert sie in einem Dataframe und ruft für jeden Artikel das clean_html-Skript und die Intent-processing-Skripte auf. Die extrahierten Informationen werden in einem neuen data-frame gespeichert. Außerdem wird das .tsv für den Bot generiert

<!--v-->

### Lösungsansatz - Processing

```
.
├── clean_html.R
├── get_awards.R
├── get_birthdate.R
├── get_birthplace.R
├── get_data.R
├── get_spouse.R
├── get_university.R
├── import_packages.R
├── nlp_annotate.R
└── utils.R
```
<!--s-->



### Lösungsansatz - Processing, Extraktion Intents
  
* Beispiel `R/get_awards.R`
* Nutze _NER-Entities_ und _Regex_

<!--s-->

### Lösungsansatz - Processing, Extraktion Intents

* Beispiel `R/get_spouse.R`
* Nutze _Pattern_ sowie _NER-Entities_ und _POS-Tags_

<!--s-->

### Lösungsansatz - Gesamtarchitektur

<img src="Wiki_Chatbot_Architecture.png" width="100%">
Note: Schaubild der Gesamtarchitektur einfügen, AUF JEDEN FALL mit docker-Wal

```
rasa
├── actions.py       - Custom Actions
├── domain.yml       - Entitäten, Antwortvorlagen
├── nlu.md           - Intents, Fragebeispiele
├── nlu_config.yml   - Pipeline
├── data
│   └── data.tsv     - Daten für den Bot
└── stories.md       - Gesprächsverläufe
```

<!--s-->

### Vorführung RASA - Bot

Note: I see what you did there

<!--s-->

### Inhalt

* ~~Thema & Forschungsfrage~~
* ~~Lösungsansatz~~
* Ergebnisse

<!--s-->

### Ergebnisse mit Plots

<img src="plots/feature_count_flip.png" width="40%">
Note: fancy plots mit precision und recall zu awards, birthdate und spouse

<!--s-->

### Bewertung Software/Datengrundlage II

#### 1. Rasa-Bot
* (+) NLP funktioniert in Rasa sehr gut
* (+) Frei konfigurierbares Skript (actions.py)
* (-) RASA-Software schwierig aufzusetzen (keine Dokumentation in Beispielen, keine Beispiele in der Dokumentation)
* (-) RASA wurde kurz vor Projektbeginn stark umgestellt (Tutorial, Dokumenation schlagartig veraltet)

<!--s-->

### Bewertung Software/Datengrundlage II

#### 2. Wikipedia Artikel als unstrukturierte Datengrundlage

* (+) Relativ ähnlicher Aufbau
* (-) Dennoch im Detail Unterschiede ("persönliche Note" unterschiedlicher Autoren)
* (-) Unterschiedlich ausführlich, tlw. Fehlen von Daten

<!--s-->

### Beantwortung der Forschungsfrage

* Definieren der Intents für den Bot sollte vorab geschehen  
* Informationen zu Intents unterschiedlich schwierig aus Text zu extrahieren  
Note: Wäre möglich, aber nicht sinnvoll, denn Intents sind Grundlage für Funktionieren von Rasa-Architektur; Verfahren teilweise allgemein verwendbar, tlw. auch von der Domäne abhängig

<!--s-->

### Ergebnisse

(_Kann man dieses Wissen aus Texten akquirieren?_)  
(_Kann man dies automatische mit Textquellen geschehen?_)

* **Abschließend**: Es ist möglich, Wissen aus den Texten zu akquirieren, wenn im Vorhinein Intents festgelegt werden und dieses Wissen kann automatisch dem Bot zugeführt werden.

<!--s-->
